@@ -2,18 +2,22 @@ from loguru import logger
 from proxypool.storages.redis import RedisClient
 from proxypool.setting import PROXY_NUMBER_MAX, NEED_LOG_GETTER
 from proxypool.crawlers import __all__ as crawlers_cls
-
+from proxypool.storages.proxy_dict import ProxyDict
 
 class Getter(object):
     """
     getter of proxypool
     """
 
-    def __init__(self, redis_host, redis_port, redis_password, redis_database, need_log=True):
+    def __init__(self, redis_host, redis_port, redis_password, redis_database, storage="redis", need_log=True):
         """
         init db and crawlers
         """
-        self.redis = RedisClient(host=redis_host, port=redis_port, password=redis_password, db=redis_database)
+        # self.redis = RedisClient(host=redis_host, port=redis_port, password=redis_password, db=redis_database)
+        if storage == "redis":
+            self.conn = RedisClient(host=redis_host, port=redis_port, password=redis_password, db=redis_database)
+        else:
+            self.conn = ProxyDict()
         self.crawlers_cls = crawlers_cls
         self.crawlers = [crawler_cls() for crawler_cls in self.crawlers_cls]
         self.need_log = need_log
@@ -23,7 +27,7 @@ class Getter(object):
         if proxypool if full
         return: bool
         """
-        return self.redis.count() >= PROXY_NUMBER_MAX
+        return self.conn.count() >= PROXY_NUMBER_MAX
 
     @logger.catch
     def run(self):
@@ -37,7 +41,7 @@ class Getter(object):
             if self.need_log:
                 logger.info(f'crawler {crawler} to get proxy')
             for proxy in crawler.crawl():
-                self.redis.add(proxy)
+                self.conn.add(proxy)
 
 
 if __name__ == '__main__':
